camelot.camelot.view.forms.TabForm

Package camelot :: Package camelot :: Package view :: Module forms :: Class TabForm |
[hide private]
[frames] | no frames]

# Class TabForm

source code

Render forms within a QTabWidget

Instance Methods | [hide private]
__init__(self, tabs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
render(self, widgets, parent=None, nomargins=False) | source code
Inherited from `Form`: `get_fields` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, tabs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Parameters: `tabs` - a list of tuples of (tab_label, tab_form) Overrides: object.__init__

### render(self, widgets, parent=None, nomargins=False) | source code
Parameters: `widgets` - a dictionary mapping each field in this form to a tuple of (label, widget editor) @return : a QWidget into which the form is rendered Overrides: Form.render (inherited documentation)